pub fn core_dir_program(name: &str) -> Option<PathBuf>Expand description
Return the path at which the Git-provided program with bare name resides within the core_dir(),
or None if it doesn’t exist there or if Git could not be found.
This is the location git itself uses to find the programs implementing its subcommands, and is
useful to invoke programs like git-upload-pack that are shipped with Git but aren’t necessarily
present in PATH.
Note that installations differ in which programs they provide as separate executables - builds
with SKIP_DASHED_BUILT_INS, like Git for Windows, omit programs for builtin subcommands, which
can then still be run through git itself.