installation_program

Function installation_program 

pub fn installation_program(name: &str) -> Option<PathBuf>
Return the path at which a program distributed with Git resides, or None if it cannot be found.

Unlike core_dir_program(), which searches only core_dir(), this also searches the bin and usr/bin directories of the Git for Windows installation on Windows. These contain programs such as sh, vim, and, in some versions, vi.

Only a bare program name without path separators is accepted.